# Aio-pika Macrobase Driver
Use wrapper for the Pika for asyncio and humans. With him.
[![Build Status](https://api.travis-ci.com/mbcores/aiopika-macrobase.svg)](https://travis-ci.com/github/mbcores/aiopika-macrobase)

Driver with [aio-pika](https://github.com/mosquito/aio-pika/) implementation from [Macrobase framework](https://github.com/mbcores/macrobase).